``gdsfactory``
==============

GDSFactory is an incredibly complete design package with very active development. The focus of implementing a `gdsfactory` microservice in `piel` is to provide translation functions specific to common methdologies in the codesign tools used by `piel`. Similar functions may be required by others depending on their design flow, but these are the defaults for ``piel``.

.. toctree::

    ../../../autoapi/piel/tools/gdsfactory/index.rst
